@@ -82,15 +82,3 @@ def test_json_search_filtered():
     assert 'charset' not in response['content-type']
     info = simplejson.loads(content)
     assert len(info) == 30
-
-
-def test_funky_encoding():
-    """
-    Handling of funky query strings is different per Python version.
-    """
-    response, content = http.requestU(
-            'http://our_test_domain:8001/search?q=title:\"\xd3ptica%20electromagn\xe9tica\"')
-    if sys.version_info[0] < 3:
-        assert response['status'] == '400', content
-    else:
-        assert response['status'] == '200', content
