@@ -3,53 +3,60 @@ Test a full suite of unicode interactions.
 """
 
 
-import urllib
-import httplib2
+from tiddlyweb.fixups import unquote
 import simplejson
 
-from fixtures import muchdata, reset_textstore, _teststore, initialize_app
+from .fixtures import (reset_textstore, _teststore, initialize_app,
+        get_http)
 from tiddlyweb.model.recipe import Recipe
 from tiddlyweb.model.tiddler import Tiddler
 from tiddlyweb.model.bag import Bag
 
 encoded_name = 'aaa%25%E3%81%86%E3%81%8F%E3%81%99'
-name = urllib.unquote(encoded_name).decode('utf-8')
+name = unquote(encoded_name)
+http = get_http()
+
 
 def setup_module(module):
     initialize_app()
     reset_textstore()
     module.store = _teststore()
-    #muchdata(module.store)
+
 
 def test_put_unicode_bag():
-    http = httplib2.Http()
     encoded_bag_name = encoded_name
     bag_name = name
 
     bag_policy = dict(delete=[bag_name])
-    bag_json = simplejson.dumps({'policy':bag_policy})
-    response, content = http.request('http://our_test_domain:8001/bags/%s' % encoded_bag_name,
-            method='PUT', body=bag_json, headers={'Content-Type': 'application/json'})
+    bag_json = simplejson.dumps({'policy': bag_policy})
+    response, content = http.requestU(
+            'http://our_test_domain:8001/bags/%s' % encoded_bag_name,
+            method='PUT',
+            body=bag_json,
+            headers={'Content-Type': 'application/json'})
     assert response['status'] == '204'
 
     bag = Bag(bag_name)
     bag = store.get(bag)
     assert bag.policy.delete == bag_policy['delete']
     assert bag.name == bag_name
-    assert type(bag.name) == unicode
+
 
 def test_put_unicode_tiddler():
-    http = httplib2.Http()
     encoded_tiddler_name = encoded_name
     tiddler_name = name
     encoded_bag_name = encoded_name
     bag_name = name
 
     tiddler_text = u'hello %s' % name
-    tiddler_json = simplejson.dumps(dict(modifier=name,text=tiddler_text,tags=[name]))
-    response, content = http.request('http://our_test_domain:8001/bags/%s/tiddlers/%s' \
+    tiddler_json = simplejson.dumps(dict(modifier=name,
+        text=tiddler_text, tags=[name]))
+    response, content = http.requestU(
+            'http://our_test_domain:8001/bags/%s/tiddlers/%s'
             % (encoded_bag_name, encoded_tiddler_name),
-            method='PUT', body=tiddler_json, headers={'Content-Type':'application/json'})
+            method='PUT',
+            body=tiddler_json,
+            headers={'Content-Type': 'application/json'})
 
     assert response['status'] == '204'
 
@@ -59,17 +66,19 @@ def test_put_unicode_tiddler():
     assert tiddler.text == tiddler_text
     assert tiddler.tags == [name]
 
+
 def test_put_unicode_recipe():
-    http = httplib2.Http()
     encoded_recipe_name = encoded_name
     recipe_name = name
-    encoded_bag_name = encoded_name
     bag_name = name
 
     recipe_list = [[bag_name, '[tag[%s]]' % name]]
     json_recipe_list = simplejson.dumps(dict(recipe=recipe_list))
-    response, content = http.request('http://our_test_domain:8001/recipes/%s' % encoded_recipe_name,
-            method='PUT', body=json_recipe_list, headers={'Content-Type':'application/json'})
+    response, content = http.requestU(
+            'http://our_test_domain:8001/recipes/%s' % encoded_recipe_name,
+            method='PUT',
+            body=json_recipe_list,
+            headers={'Content-Type': 'application/json'})
     assert response['status'] == '204'
 
     recipe = Recipe(recipe_name)
@@ -77,16 +86,18 @@ def test_put_unicode_recipe():
     assert recipe.get_recipe() == recipe_list
     assert recipe.name == recipe_name
 
+
 def test_get_tiddlers_from_recipe():
     get_tiddlers_from_thing('recipes')
 
+
 def test_get_tiddlers_from_bag():
     get_tiddlers_from_thing('bags')
 
-def test_filter_tiddlers():
-    http = httplib2.Http()
 
-    response, content = http.request('http://our_test_domain:8001/bags/%s/tiddlers.json?select=tag:%s' \
+def test_filter_tiddlers():
+    response, content = http.requestU(
+            'http://our_test_domain:8001/bags/%s/tiddlers.json?select=tag:%s'
             % (encoded_name, encoded_name),
             method='GET')
     assert response['status'] == '200'
@@ -96,6 +107,7 @@ def test_filter_tiddlers():
     assert info[0]['bag'] == name
     assert len(info) == 1
 
+
 def test_double_uri_encoded_title():
     """
     This test works against wsgi-intercept but fails when
@@ -108,10 +120,9 @@ def test_double_uri_encoded_title():
     See: https://github.com/tiddlyweb/tiddlyweb/issues/86
          https://mail.python.org/pipermail/web-sig/2008-January/thread.html#3122
     """
-    http = httplib2.Http()
     store.put(Bag('double'))
 
-    response, content = http.request(
+    response, content = http.requestU(
             'http://our_test_domain:8001/bags/double/tiddlers/test%2520one',
             method='PUT',
             headers={'Content-Type': 'application/json'},
@@ -122,17 +133,19 @@ def test_double_uri_encoded_title():
     tiddler = store.get(Tiddler('test%20one', 'double'))
     assert tiddler.title == 'test%20one'
 
-def get_tiddlers_from_thing(container):
-    http = httplib2.Http()
 
-    response, content = http.request('http://our_test_domain:8001/%s/%s/tiddlers.json' % (container, encoded_name),
+def get_tiddlers_from_thing(container):
+    response, content = http.requestU(
+            'http://our_test_domain:8001/%s/%s/tiddlers.json' % (
+                container, encoded_name),
             method='GET')
     assert response['status'] == '200'
     tiddler_info = simplejson.loads(content)
     assert tiddler_info[0]['title'] == name
     assert tiddler_info[0]['tags'] == [name]
 
-    response, content = http.request('http://our_test_domain:8001/%s/%s/tiddlers/%s.json' \
+    response, content = http.requestU(
+            'http://our_test_domain:8001/%s/%s/tiddlers/%s.json'
             % (container, encoded_name, encoded_name),
             method='GET')
     assert response['status'] == '200'
